@@ -4,7 +4,7 @@ use warnings;
 
 use 5.008003;
 
-our $VERSION = '0.09_03';
+our $VERSION = '0.10_01';
 
 use constant K_DEBUG => 0;
 
@@ -51,6 +51,9 @@ MODULE = KinoSearch    PACKAGE = KinoSearch
 
 PROTOTYPES: disable
 
+BOOT:
+    items = 0;
+
 =for comment
 Return 1 if memory debugging is enabled.  See KinoSearch::Util::MemManager.
 
@@ -71,7 +74,7 @@ KinoSearch - search engine library
 
 =head1 VERSION
 
-0.09_03
+0.10
 
 =head1 WARNING
 
@@ -146,6 +149,11 @@ Extremely fast and scalable - can handle millions of documents
 
 =item *
 
+Incremental indexing (addition/deletion of documents to/from an existing
+index).
+
+=item *
+
 Full support for 12 Indo-European languages.
 
 =item *
@@ -225,6 +233,11 @@ is not compatible with either.
 KinoSearch is named for Kino, the main character in John Steinbeck's novella,
 "The Pearl".
 
+=head1 SUPPORT
+
+Please direct support questions to the kinosearch mailing list: subscription
+information at L<http://www.rectangular.com/kinosearch>.
+
 =head1 AUTHORS
 
 Marvin Humphrey, E<lt>marvin at rectangular dot comE<gt>
