@@ -22,6 +22,7 @@ new( class_sv, doc_freq, frq_fileptr, prx_fileptr, skip_offset, index_fileptr )
 PREINIT:
     TermInfo *tinfo;
 CODE:
+    class_sv = NULL; /* suppress "unused variable" warning */
     Kino_New(0, tinfo, 1, TermInfo);
     tinfo->doc_freq      = doc_freq;
     tinfo->frq_fileptr   = frq_fileptr;
@@ -81,11 +82,7 @@ ALIAS:
     get_index_fileptr = 10
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  tinfo->doc_freq = SvIV(ST(1));
              /* fall through */
@@ -112,8 +109,7 @@ CODE:
     case 10: RETVAL = newSVnv(tinfo->index_fileptr);
              break;
         
-    default: Kino_confess("Internal error: _set_or_get invalid ix: %d", ix);
-    }
+    KINO_END_SET_OR_GET_SWITCH
 }
     OUTPUT: RETVAL
 
@@ -183,7 +179,7 @@ Kino_TInfo_reset(TermInfo *tinfo) {
     tinfo->prx_fileptr   = 0.0;
     tinfo->skip_offset   = 0;
     tinfo->index_fileptr = 0.0;
-};
+}
 
 void 
 Kino_TInfo_destroy(TermInfo *tinfo) {
@@ -228,7 +224,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
