@@ -1,4 +1,6 @@
 package KinoSearch::Search::HitQueue;
+use strict;
+use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::PriorityQueue );
 
@@ -6,12 +8,21 @@ use KinoSearch::Search::HitDoc;
 
 our %instance_vars = __PACKAGE__->init_instance_vars();
 
+sub new {
+    my $either = shift;
+    my $self   = $either->SUPER::new(@_);
+
+    $self->define_less_than;
+
+    return $self;
+}
+
 # Create an array of "empty" HitDoc objects -- they have scores and doc_nums,
 # but the stored fields have yet to be retrieved.
 sub hit_docs {
     my $self = shift;
 
-    # decode score/doc_num scalars into HitDocs
+    # transform score/doc_num scalars into HitDoc objects
     my @hit_docs = map {
         KinoSearch::Search::HitDoc->new(
             doc_num => unpack( 'N', "$_" ),
@@ -30,10 +41,10 @@ __XS__
 MODULE = KinoSearch    PACKAGE = KinoSearch::Search::HitQueue
 
 void
-define_less_than(obj)
-    PriorityQueue *obj;
+define_less_than(hitq)
+    PriorityQueue *hitq;
 PPCODE:
-    obj->less_than = &Kino_HitQ_less_than;
+    hitq->less_than = &Kino_HitQ_less_than;
 
 __H__
 
@@ -93,7 +104,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.05_05.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
