@@ -69,11 +69,7 @@ ALIAS:
     get_similarity = 2
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        croak("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  SvREFCNT_dec(scorer->similarity_sv);
              scorer->similarity_sv = newSVsv( ST(1) );
@@ -82,7 +78,8 @@ CODE:
              /* fall through */
     case 2:  RETVAL = newSVsv(scorer->similarity_sv);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -236,21 +233,25 @@ Kino_Scorer_new() {
 float
 Kino_Scorer_score_death(Scorer* scorer) {
     Kino_confess("scorer->score must be defined in a subclass");
+    return 1.0;
 }
 
 bool
 Kino_Scorer_next_death(Scorer* scorer) {
     Kino_confess("scorer->next must be defined in a subclass");
+    return 1;
 }
 
 U32
 Kino_Scorer_doc_death(Scorer* scorer) {
     Kino_confess("scorer->doc must be defined in a subclass");
+    return 1;
 }
 
 bool
 Kino_Scorer_skip_to_death(Scorer* scorer, U32 target_doc_num) {
     Kino_confess("scorer->skip_to must be defined in a subclass");
+    return 1;
 }
 
 void
@@ -281,7 +282,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
