@@ -131,11 +131,7 @@ ALIAS:
     get_fh       = 6
 CODE:
 {
-     /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  instream->len = SvNV( ST(1) );
              /* fall through */
@@ -151,7 +147,8 @@ CODE:
              /* fall through */
     case 6:  RETVAL = newSVsv(instream->fh_sv);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -273,6 +270,7 @@ PPCODE:
             break;
 
         default: 
+            aSV = NULL; /* suppress unused var compiler warning */
             Kino_confess("Invalid type in template: '%c'", sym);
         }
 
@@ -615,7 +613,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
