@@ -188,11 +188,7 @@ PREINIT:
     char   *new_bits;
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        croak("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  new_capacity = SvUV(ST(1));
              if (new_capacity < bit_vec->capacity) {
@@ -214,8 +210,7 @@ CODE:
              RETVAL = newSVpv((char*)bit_vec->bits, len);
              break;
 
-    default: Kino_confess("Internal error: _set_or_get ix: %d", ix); 
-    }
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -250,6 +245,7 @@ typedef struct bitvector {
 BitVector* Kino_BitVec_new(U32);
 BitVector* Kino_BitVec_clone(BitVector*);
 void Kino_BitVec_grow(BitVector*, U32);
+void Kino_BitVec_shrink(BitVector *, U32);
 void Kino_BitVec_set(BitVector*, U32);
 void Kino_BitVec_clear(BitVector*, U32);
 void Kino_BitVec_bulk_set(BitVector*, U32, U32);
@@ -327,7 +323,7 @@ Kino_BitVec_grow(BitVector *bit_vec, U32 capacity) {
 
 void 
 Kino_BitVec_shrink(BitVector *bit_vec, U32 capacity) {
-    U32 old_byte_size, byte_size;
+    U32 byte_size;
     
     if (capacity >= bit_vec->capacity)
         return;
@@ -560,7 +556,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
