@@ -18,21 +18,37 @@ __H__
 #include "XSUB.h"
 #include "KinoSearchUtilCarp.h"
 
+#define KINO_START_SET_OR_GET_SWITCH                                \
+    /* if called as a setter, make sure the extra arg is there */   \
+    if (ix % 2 == 1 && items != 2)                                  \
+        croak("usage: $seg_term_enum->set_xxxxxx($val)");           \
+    switch (ix) {
+
+#define KINO_END_SET_OR_GET_SWITCH                                  \
+    default: Kino_confess("Internal error. ix: %d", ix);            \
+			 RETVAL = &PL_sv_undef; /* quiet compiler warning */    \
+             break; /* probably unreachable */                      \
+    }
+
 #define Kino_extract_struct( perl_obj, dest, cname, class ) \
      if (sv_derived_from( perl_obj, class )) {              \
          IV tmp = SvIV( (SV*)SvRV(perl_obj) );              \
          dest = INT2PTR(cname, tmp);                        \
      }                                                      \
-     else                                                   \
-         Kino_confess("not a %s", class); 
+     else {                                                 \
+         dest = NULL; /* suppress unused var warning */     \
+         Kino_confess("not a %s", class);                   \
+     }
 
 #define Kino_extract_anon_struct( perl_obj, dest )                  \
      if (sv_derived_from( perl_obj, "KinoSearch::Util::CClass" )) { \
          IV tmp = SvIV( (SV*)SvRV(perl_obj) );                      \
          dest = INT2PTR(void*, tmp);                                \
      }                                                              \
-     else                                                           \
-         Kino_confess("not derived from KinoSearch::Util::CClass"); 
+     else {                                                         \
+         dest = NULL; /* suppress unused var warning */             \
+         Kino_confess("not derived from KinoSearch::Util::CClass"); \
+     }
 
 #define Kino_extract_struct_from_hv(hash, dest, key, key_len, cname, class) \
     {                                                                       \
@@ -44,8 +60,10 @@ __H__
             IV tmp = SvIV( (SV*)SvRV(*sv_ptr) );                            \
             dest   = INT2PTR(cname, tmp);                                   \
         }                                                                   \
-        else                                                                \
+        else {                                                              \
+            dest = NULL; /* suppress unused var warning */                  \
             Kino_confess("not a %s", class);                                \
+        }                                                                   \
     }
 
 #endif /* include guard */
@@ -69,7 +87,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
