@@ -98,7 +98,7 @@ Kino_Verify_do_build_args_hash(char* defaults_hash_name, I32 stack_st) {
 
     /* make the args hash a copy of the defaults hash */
     (void)hv_iterinit(defaults_hash);
-    while (val_sv = hv_iternextsv(defaults_hash, &key, &key_len)) {
+    while ((val_sv = hv_iternextsv(defaults_hash, &key, &key_len))) {
         val_copy_sv = newSVsv(val_sv);
         hv_store(args_hash, key, key_len, val_copy_sv, 0);
     }
@@ -153,7 +153,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
